rhodent
=======

**rhodent** is a tool for analyzing hot-carrier distributions based on input from real-time time-dependent density functional theory simulations.
A detailed description of the functionality provided as well as tutorials can be found in the `user guide <https://rhodent.materialsmodeling.org/>`_.

**rhodent** can be installed via `pip`::

    pip3 install rhodent

**rhodent** has been developed at the `Department of Physics <https://www.chalmers.se/en/departments/physics/>`_ of `Chalmers University of Technology <https://www.chalmer
s.se/>`_ (Gothenburg, Sweden) in the `Condensed Matter and Materials Theory division <http://www.materialsmodeling.org>`_.
